# Frequenz Repository Configuration Release Notes

## Summary

This release adds support for `pylint` 3, so downstream projects can upgrade their `pylint` version.

## Upgrading

If upgrading `pylint` you might get a few new check errors.

### Cookiecutter template

There is no need to regenerate any templates with this release.

## Bug Fixes

- `mkdocs`: The `conftest` module is now properly hidden from the documentation again.
